summaryrefslogtreecommitdiffstats
path: root/modules
diff options
context:
space:
mode:
authorGraham Leggett <minfrin@apache.org>2002-08-08 19:59:18 +0200
committerGraham Leggett <minfrin@apache.org>2002-08-08 19:59:18 +0200
commit7f74fe4231995e443877632ce565b7d9100c703b (patch)
treec4babd5914ec16a97337e7436d23972260429790 /modules
parentfix typo (diff)
downloadapache2-7f74fe4231995e443877632ce565b7d9100c703b.tar.xz
apache2-7f74fe4231995e443877632ce565b7d9100c703b.zip
Fix proxy so that it is possible to access ftp: URLs via a proxy
chain. PR: Obtained from: Submitted by: Peter Van Biesen <peter.vanbiesen@vlafo.be> Reviewed by: Graham Leggett <minfrin@apache.org> git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@96320 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'modules')
-rw-r--r--modules/proxy/proxy_http.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/modules/proxy/proxy_http.c b/modules/proxy/proxy_http.c
index bce637b2c2..372565ab74 100644
--- a/modules/proxy/proxy_http.c
+++ b/modules/proxy/proxy_http.c
@@ -1032,10 +1032,10 @@ int ap_proxy_http_handler(request_rec *r, proxy_server_conf *conf,
}
is_ssl = 1;
}
- else if (strncasecmp(url, "http:", 5)) {
+ else if (!(strncasecmp(url, "http:", 5)==0 || (strncasecmp(url, "ftp:", 4)==0 && proxyname))) {
ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, r->server,
"proxy: HTTP: declining URL %s", url);
- return DECLINED; /* only interested in HTTP */
+ return DECLINED; /* only interested in HTTP, or FTP via proxy */
}
ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, r->server,
"proxy: HTTP: serving URL %s", url);